/// <reference types="mathjax2" />

import { MathJaxConfig as MathJaxConfig_2 } from 'mathjax-full/js/components/startup';
import { MathJaxObject as MathJaxObject_2 } from 'mathjax-full/js/components/startup';

export declare const createMathJaxRenderer: <T extends Partial<MathJax2RendererConfig | MathJax3RendererConfig>>(rendererConfig: T) => IMathRenderer<MathEngine.MathJax2> | IMathRenderer<MathEngine.MathJax3>;

export declare interface IMathRenderer<TEngine extends MathEngine> {
    config(value: Partial<RendererConfig<TEngine>>): this;
    render(container: HTMLElement, callback?: () => unknown): Promise<void>;
}

export declare enum MathEngine {
    MathJax2 = 0,
    MathJax3 = 1
}

export declare type MathJax2RendererConfig = RendererConfig<MathEngine.MathJax2> & {
    engine: MathEngine.MathJax2;
};

export declare type MathJax3RendererConfig = RendererConfig<MathEngine.MathJax3> & {
    engine: MathEngine.MathJax3;
};

declare type MathJaxConfig = MathJaxConfig_2 & {
    tex: Record<string, unknown>;
    [name: string]: unknown;
};

declare interface MathJaxObject {
    config: MathJaxConfig;
    startup: MathJaxObject_2['startup'];
    typeset(arg: unknown[]): void;
    typesetPromise(arg: unknown[]): Promise<void>;
}

export declare interface RendererConfig<TEngine extends MathEngine> {
    engine: MathEngine;
    entryScript: string;
    document: Document;
    isEnabled: boolean;
    onRendered?: (mathjax: TEngine extends MathEngine.MathJax2 ? typeof MathJax : MathJaxObject) => void | Promise<void>;
    tapMathJaxConfig?: <TConfig = TEngine extends MathEngine.MathJax2 ? MathJax.Config : MathJaxConfig>(config: TConfig) => TConfig;
}

export { }
